/***********************************************************************************************************************************
Server Ping Command
***********************************************************************************************************************************/
#ifndef COMMAND_SERVER_PING_H
#define COMMAND_SERVER_PING_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
FN_EXTERN void cmdServerPing(void);

#endif
